@@ -1,11 +1,9 @@
 library(AER)
-library(Amelia)
 library(dplyr)
 library(geepack)
-library(MatchIt)
 library(survey)
 library(testthat)
-library(Zelig)
+library(zeligverse)
 
 set.seed(123)
 test_check("Zelig")
